@@ -7,7 +7,7 @@ from concurrent import futures
 from json import JSONDecodeError
 from os import path
 from time import sleep
-from typing import Optional
+from typing import Optional, Dict
 
 import boto3
 import dpath.util
@@ -346,17 +346,17 @@ class BcPlatformIntegration(object):
             self.get_checkov_mapping_metadata()
         return self.guidelines
 
-    def get_id_mapping(self) -> dict:
+    def get_id_mapping(self) -> Dict[str, str]:
         if not self.bc_id_mapping:
             self.get_checkov_mapping_metadata()
         return self.bc_id_mapping
 
-    def get_ckv_to_bc_id_mapping(self) -> dict:
+    def get_ckv_to_bc_id_mapping(self) -> Dict[str, str]:
         if not self.ckv_to_bc_id_mapping:
             self.get_checkov_mapping_metadata()
         return self.ckv_to_bc_id_mapping
 
-    def get_checkov_mapping_metadata(self) -> Optional[dict]:
+    def get_checkov_mapping_metadata(self) -> None:
         if self.bc_skip_mapping is True:
             logging.debug("Skipped mapping API call")
             self.ckv_to_bc_id_mapping = {}
@@ -428,7 +428,7 @@ class BcPlatformIntegration(object):
 
                         print(Style.BRIGHT + colored("Or download our VS Code plugin:  https://github.com/bridgecrewio/checkov-vscode \n", 'cyan',attrs=['bold']))
 
-                        print(Style.BRIGHT + colored( "Interested in contributing to Checkov as an open source developer.  We thought you’d never ask.  Check us out at: \nhttps://github.com/bridgecrewio/checkov/issues?q=is%3Aopen+is%3Aissue+label%3A%22good+first+issue%22 \n", 'white', attrs=['bold']))
+                        print(Style.BRIGHT + colored("Interested in contributing to Checkov as an open source developer.  We thought you’d never ask.  Check us out at: \nhttps://github.com/bridgecrewio/checkov/issues?q=is%3Aopen+is%3Aissue+label%3A%22good+first+issue%22 \n", 'white', attrs=['bold']))
 
                     else:
                         print(
