@@ -24,7 +24,7 @@ STACK_TAGS_TOKEN = 'stackTags'  # nosec
 TAGS_TOKEN = 'tags'  # nosec
 SUPPORTED_PROVIDERS = ['aws']
 
-DEFAULT_VAR_PATTERN = r"\${([^{}]+?)}"
+DEFAULT_VAR_PATTERN = re.compile(r"\${([^{}]+?)}")
 QUOTED_WORD_SYNTAX = re.compile(r"(?:('|\").*?\1)")
 FILE_LOCATION_PATTERN = re.compile(r'^file\(([^?%*:|"<>]+?)\)')
 
@@ -33,7 +33,7 @@ def parse(filename):
     template = None
     template_lines = None
     try:
-        (template, template_lines) = cfn_yaml.load(filename)
+        (template, template_lines) = cfn_yaml.load(filename, cfn_yaml.ContentType.SLS)
         if not template or not is_checked_sls_template(template):
             return
     except IOError as e:
