@@ -1,5 +1,5 @@
 import re
-from typing import Dict, List, Any
+from typing import Dict, List, Any, Pattern
 
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.terraform.checks.provider.base_check import BaseProviderCheck
@@ -10,8 +10,8 @@ class LinodeCredentials(BaseProviderCheck):
     def __init__(self) -> None:
         name = "Ensure no hard coded Linode tokens exist in provider"
         id = "CKV_LIN_1"
-        supported_provider = ["linode"]
-        categories = [CheckCategories.SECRETS]
+        supported_provider = ("linode",)
+        categories = (CheckCategories.SECRETS,)
         super().__init__(name=name, id=id, categories=categories, supported_provider=supported_provider)
 
     def scan_provider_conf(self, conf: Dict[str, List[Any]]) -> CheckResult:
@@ -20,7 +20,7 @@ class LinodeCredentials(BaseProviderCheck):
         return CheckResult.PASSED
 
     @staticmethod
-    def secret_found(conf: Dict[str, List[Any]], field: str, pattern: str) -> bool:
+    def secret_found(conf: Dict[str, List[Any]], field: str, pattern: Pattern[str]) -> bool:
         if field in conf.keys():
             value = conf[field][0]
             if re.match(pattern, value) is not None:
