@@ -1,5 +1,6 @@
 from abc import abstractmethod
-from typing import Dict, List, Any
+from collections.abc import Iterable
+from typing import Dict, List, Any, Optional
 
 from checkov.common.checks.base_check import BaseCheck
 from checkov.common.models.enums import CheckResult, CheckCategories
@@ -8,11 +9,21 @@ from checkov.terraform.parser_functions import handle_dynamic_values
 
 
 class BaseResourceCheck(BaseCheck):
-    def __init__(self, name: str, id: str, categories: List[CheckCategories], supported_resources: List[str],
-                 guideline=None) -> None:
+    def __init__(
+        self,
+        name: str,
+        id: str,
+        categories: "Iterable[CheckCategories]",
+        supported_resources: "Iterable[str]",
+        guideline: Optional[str] = None,
+    ) -> None:
         super().__init__(
-            name=name, id=id, categories=categories, supported_entities=supported_resources,
-            block_type="resource", guideline=guideline
+            name=name,
+            id=id,
+            categories=categories,
+            supported_entities=supported_resources,
+            block_type="resource",
+            guideline=guideline,
         )
         self.supported_resources = supported_resources
         resource_registry.register(self)
